<?php

namespace FiloBlu\Rma\Plugin\Rma\Api\RmaRepositoryInterface;


use Magento\Framework\App\ResourceConnection;
use Magento\Sales\Api\OrderRepositoryInterface;
use Psr\Log\LoggerInterface;
use FiloBlu\Rma\Api\RmaExtensionAttributesRepositoryInterface;

class AfterGet
{
    /**
     * @var OrderRepositoryInterface
     */
    private $orderRepository;
    /**
     * @var \Magento\Rma\Api\Data\ItemExtensionInterfaceFactory
     */
    private $extensionInterfaceFactory;
    /**
     * @var ResourceConnection
     */
    private $resourceConnection;
    /**
     * @var LoggerInterface
     */
    protected $logger;

    /**
     * @var RmaExtensionAttributesRepositoryInterface
     */
    protected $rmaExtensionAttributesRepository;

    /**
     * AfterGet constructor.
     * @param OrderRepositoryInterface $orderRepository
     * @param \Magento\Rma\Api\Data\ItemExtensionInterfaceFactory $extensionInterfaceFactory
     * @param ResourceConnection $resourceConnection
     * @param LoggerInterface $logger
     * @param RmaExtensionAttributesRepositoryInterface $rmaExtensionAttributesRepository
     */
    public function __construct(OrderRepositoryInterface $orderRepository,
                                \Magento\Rma\Api\Data\ItemExtensionInterfaceFactory $extensionInterfaceFactory,
                                ResourceConnection $resourceConnection,
                                LoggerInterface $logger,
                                RmaExtensionAttributesRepositoryInterface $rmaExtensionAttributesRepository)

    {
        $this->orderRepository = $orderRepository;
        $this->extensionInterfaceFactory = $extensionInterfaceFactory;
        $this->resourceConnection = $resourceConnection;
        $this->logger = $logger;
        $this->rmaExtensionAttributesRepository = $rmaExtensionAttributesRepository;
    }

    /**
     * @param \Magento\Rma\Api\RmaRepositoryInterface $subject
     * @param \Magento\Rma\Api\Data\RmaInterface $result
     * @return \Magento\Rma\Api\Data\RmaInterface
     */
    public function afterGet(\Magento\Rma\Api\RmaRepositoryInterface $subject, \Magento\Rma\Api\Data\RmaInterface $result)
    {
        foreach ($result->getItems() as $rmaItem) {
            $attributes = $rmaItem->getExtensionAttributes();
            if ($attributes === null) {
                /** @var \Magento\Rma\Api\Data\ItemExtensionInterface $attributes */
                $attributes = $this->extensionInterfaceFactory->create();
            }
            if($changeSizeOrderId = $this->rmaExtensionAttributesRepository->getChangeSizeOrderId($rmaItem->getEntityId())){
                try {
                    $attributes->setOrder($this->orderRepository->get($changeSizeOrderId));
                } catch (\Exception $exception) {
                    $this->logger->info($exception->getMessage());
                }

                $rmaItem->setExtensionAttributes($attributes);
            }
        }
        return $result;
    }
}